#ifndef PYTHONIC_INCLUDE_NUMPY_RANDOM_RANDOM_SAMPLE_HPP
#define PYTHONIC_INCLUDE_NUMPY_RANDOM_RANDOM_SAMPLE_HPP

#include "pythonic/include/utils/functor.hpp"
#include "pythonic/include/numpy/random/random.hpp"

PYTHONIC_NS_BEGIN
namespace numpy
{
  namespace random
  {
    USING_FUNCTOR(random_sample, random);
  }
}
PYTHONIC_NS_END

#endif
